@@ -8,7 +8,7 @@
 #include	<string.h>
 #include	<stdlib.h>
 #include	<arpa/inet.h>
-#include	<idna.h>
+#include	<idn2.h>
 
 /* Convenient function to do forward IP lookup */
 
@@ -249,7 +249,7 @@ int rfc1035_a(struct rfc1035_res *res,
 
 	/* Convert requested hostname to UTF-8, with fallback */
 
-	if (idna_to_unicode_8z8z(name, &p, 0) != IDNA_SUCCESS)
+	if (idn2_to_unicode_8z8z(name, &p, 0) != IDNA_SUCCESS)
 		return rfc1035_unicode(res, name, iaptr, iasize);
 
 	r=rfc1035_unicode(res, p, iaptr, iasize);
