@@ -1,5 +1,5 @@
 /*
-** Copyright 1998 - 2011 Double Precision, Inc.  See COPYING for
+** Copyright 1998 - 2018 Double Precision, Inc.  See COPYING for
 ** distribution information.
 */
 
@@ -22,6 +22,20 @@ extern "C" {
 }
 #endif
 
+#define RFC2045_MIME_MESSAGE_RFC822 "message/rfc822"
+#define RFC2045_MIME_MESSAGE_GLOBAL "message/global"
+
+#define RFC2045_MIME_MESSAGE_DELIVERY_STATUS "message/delivery-status"
+#define RFC2045_MIME_MESSAGE_GLOBAL_DELIVERY_STATUS \
+	"message/global-delivery-status"
+
+#define RFC2045_MIME_MESSAGE_HEADERS "text/rfc822-headers"
+#define RFC2045_MIME_MESSAGE_GLOBAL_HEADERS "message/global-headers"
+
+int rfc2045_message_content_type(const char *);
+int rfc2045_delivery_status_content_type(const char *);
+int rfc2045_message_headers_content_type(const char *);
+
 #define	RFC2045_ISMIME1(p)	((p) && atoi(p) == 1)
 #define	RFC2045_ISMIME1DEF(p)	(!(p) || atoi(p) == 1)
 
@@ -56,10 +70,13 @@ struct rfc2045 {
 	char *content_location;
 	struct  rfc2045ac *rfc2045acptr;
 	int	has8bitchars;	/* For rewriting */
+	int	hasraw8bitchars; /* For rewriting */
 	int	haslongline;	/* For rewriting */
 	unsigned rfcviolation;	/* Boo-boos */
 
 #define	RFC2045_ERR8BITHEADER	1	/* 8 bit characters in headers */
+	/* But this is now OK, in UTF8 mode */
+
 #define	RFC2045_ERR8BITCONTENT	2	/* 8 bit contents, but no 8bit
 					content-transfer-encoding */
 #define	RFC2045_ERR2COMPLEX	4	/* Too many nested contents */
@@ -69,9 +86,22 @@ struct rfc2045 {
 
 	char	*rw_transfer_encoding;	/* For rewriting */
 
+	/* Use quoted-printable for 8bit content */
 #define	RFC2045_RW_7BIT	1
+
+	/*
+	** Convert quoted-printable, if the resulting line length is not
+	** excessive.
+	*/
+
 #define	RFC2045_RW_8BIT	2
 
+	/*
+	** Convert quoted printable without checking for maximum resulting
+	** line length.
+	*/
+#define RFC2045_RW_8BIT_ALWAYS 3
+
 	/* Subsections */
 
 	struct rfc2045 *firstpart, *lastpart;
@@ -546,6 +576,13 @@ struct rfc2045_decodemsgtoutf8_cb {
 ** Do not prepend name: to converted header content.
 */
 
+
+#define RFC2045_DECODEMSG_NOATTACHHEADERS 0x08
+/*
+** Do not decode MIME headers of attachments. Decode only the message's
+** main headers.
+*/
+
 /*
 ** Convert a message into a utf8 bytestream. The output produced by this
 ** function is a catentation of decoded header and text content data, converted
@@ -647,6 +684,30 @@ void rfc2231_paramDecode(struct rfc2231param *paramList,
 			 int *langLen,
 			 int *textLen);
 
+/*
+** Encode an E-mail address as utf-8 address type specified in RFC 6533.
+** The e-mail address parameter must be encoded in UTF-8.
+**
+** The E-mail address is encoded as "rfc822" address type if it has only
+** ASCII characters, or if use_rfc822 is set to non0.
+**
+** A malloc-ed address gets returned.
+*/
+
+char *rfc6533_encode(const char *address, int use_rfc822);
+
+/*
+** Decode a utf-8 or an rfc-822 address type. Returns a malloc-ed buffer,
+** or NULL if the address cannot be decoded.
+**
+** Assumes valid UTF-8 coding, and does not verify it.
+**
+** Does verify, for both rfc-822 and utf-8 formats, that the returned address
+** does not contain control characters.
+*/
+
+char *rfc6533_decode(const char *address);
+
 #if 0
 {
 #endif
