@@ -2397,6 +2397,7 @@ static void emiturl(struct msg2html_textplain_info *info)
 {
 	size_t url_size=info->urlindex;
 	char save_char;
+	size_t i;
 
 	text_process_decor_apostrophe(info);
 	set_text_decor(info, info->text_decor_state);
@@ -2410,6 +2411,20 @@ static void emiturl(struct msg2html_textplain_info *info)
 		--url_size;
 	}
 
+	/* A practical joker typed in "mailto:", and nothing else */
+
+	for (i=0; i<url_size; ++i)
+		if (info->urlbuf[i] == ':')
+			break;
+
+	if (i == url_size)
+	{
+		emit_char_buffer(info, info->urlbuf,
+				 info->urlindex,
+				 text_process_decor);
+
+		return;
+	}
 	info->urlbuf[info->urlindex]=0;
 
 	save_char=info->urlbuf[url_size];
